@@ -2,10 +2,10 @@
 # just set for compatibility
 package Lemonldap::NG::Common::Conf::Backends::JSONFile;
 
-use Lemonldap::NG::Common::Conf::File;
+use Lemonldap::NG::Common::Conf::Backends::File;
 
 our @ISA     = qw(Lemonldap::NG::Common::Conf::Backends::File);
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.0';
 
 1;
 
