@@ -6,7 +6,7 @@ use JSON;
 use Plack::Request;
 use URI::Escape;
 
-our $VERSION = '2.0.10';
+our $VERSION = '2.0.15';
 
 our @ISA = ('Plack::Request');
 
@@ -25,10 +25,6 @@ sub new {
     $self->env->{REQUEST_URI} = $self->env->{X_ORIGINAL_URI}
       if ( $self->env->{X_ORIGINAL_URI} );
     $self->env->{PATH_INFO} =~ s|//+|/|g;
-
-    #if ( my $tmp = $self->script_name ) {
-    #    $self->env->{PATH_INFO} =~ s|^$tmp|/|;
-    #}
     $self->env->{PATH_INFO} ||= '/';
     $self->env->{REQUEST_URI} =~ s|^//+|/|g;
     $self->{uri}         = uri_unescape( $self->env->{REQUEST_URI} );
@@ -38,9 +34,9 @@ sub new {
     return bless( $self, $_[0] );
 }
 
-sub data { $_[0]->{data} }
+sub data { return $_[0]->{data} }
 
-sub uri { $_[0]->{uri} }
+sub uri { return $_[0]->{uri} }
 
 sub userData {
     my ( $self, $v ) = @_;
